from typing import Annotated

from pydantic import BaseModel, AfterValidator
from snick import unwrap
import typer

from typer_repyt.settings import add_settings_subcommand, attach_settings, get_settings


def valid_alignment(value: str) -> str:
    if value not in ["good", "neutral", "evil"]:
        raise ValueError(f"{value} is an invalid alignment")
    return value


class SettingsModel(BaseModel):
    name: str
    planet: str
    is_humanoid: bool = True
    alignment: Annotated[str, AfterValidator(valid_alignment)] = "neutral"


cli = typer.Typer()
add_settings_subcommand(cli, SettingsModel)


@cli.command()
@attach_settings(SettingsModel)
def report(ctx: typer.Context):
    settings = get_settings(ctx, SettingsModel)
    print(
        unwrap(
            f"""
            Look at this {settings.alignment} {settings.name} from {settings.planet}
            {'walking' if settings.is_humanoid else 'slithering'} by.
            """
        )
    )


if __name__ == "__main__":
    cli()
